==> eventwatcher-0.4.1.tar.bz2: eventwatcher-0.4.1/src/mainwidget.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef EVENTWATCHERMAINWIDGET_H
#define EVENTWATCHERMAINWIDGET_H

#include <qmap.h>

#include <kpushbutton.h>

#include "eventview.h"

class QToolButton;

namespace EventWatcher {

// class EventView;
// class EventItem;
class EventViewItem;
class EventViewHeaderItem;
class EventViewGroupItem;

typedef QMap<QString,EventViewGroupItem*> EventViewGroupMap;

class MainWidget : public QWidget
{
Q_OBJECT
public:
    MainWidget(QWidget *parent = 0, const char *name = 0);
    virtual ~MainWidget();
public slots:
    virtual void slotEventAdded(EventItem* event);
    virtual void slotCopy();
    virtual void slotDelete();
    virtual void slotKeep();
    virtual void slotSelectAll();
    virtual void slotSetGroupItems(bool group);
    virtual void slotSetShowDeleteButtons(bool show);
    virtual void slotSetSmallActionButtons(bool small);
    virtual void slotDeleteItem(EventViewItem* item);
signals:
    void itemsSelected(bool yes);
private slots:
    void slotUpdate();
    void slotSelectionChanged(int selected);
private:
    QString groupKey(const EventItem* event) const;
    EventView *m_eventView;
    EventViewHeaderItem *m_oldHeader;
    EventViewHeaderItem *m_newHeader;
    EventViewGroupMap m_groupMap;
};

class EventActionButton : public KPushButton
{
Q_OBJECT
public:
    EventActionButton(uint eventId, EventAction action, QWidget *parent = 0, const char *name = 0);
    virtual ~EventActionButton();
protected:
    QDragObject * dragObject();
protected slots:
    void buttonClicked();
private:
    uint m_eventId;
    EventAction m_action;
};

class EventViewItem : public QObject, public EventViewItemBase
{
Q_OBJECT
public:
    EventViewItem(bool showDelte, bool smallActionButton, EventView *ev);
    virtual ~EventViewItem();

    virtual bool isSelectable() const { return true; }

    virtual void setGrouped(bool grouped) { m_grouped = grouped; }
    virtual bool grouped() const { return m_grouped; }

    virtual void setMarginLeft(int margin);
    virtual int marginLeft() const;

    virtual void setEventItem(const EventItem* item);
    virtual const EventItem* eventItem() const;

    virtual bool hasActionWidget() const;
    virtual bool hasControlWidget() const;
    virtual QRect actionWidgetGeometry() const;
    virtual QRect controlWidgetGeometry() const;

    virtual void drawContents( QPainter* p, const QPoint& pos, const QRect& clipRect ) const;

protected:
    virtual int heightForWidth(int width) const;

signals:
    void deleteItem(EventViewItem* item);

protected slots:
    virtual void slotControlClicked();

private:
    bool m_grouped;
    int m_marginLeft;

    QSimpleRichText *m_rt;

    QToolButton *m_button;

    const EventItem *m_eventItem;
    bool m_hasAction;
    bool m_hasControl;
    bool m_smallActionButton;
};

class EventViewHeaderItem : public QObject, public EventViewItemBase
{
Q_OBJECT
public:
    EventViewHeaderItem(EventView *ev);
    virtual ~EventViewHeaderItem();

    virtual bool isSelectable() const { return false; }

    virtual void setText(const QString& text) { m_text = text; };
    virtual const QString& text() const { return m_text; };

    virtual void setDisplayChildNumber(bool y) { m_displayChildNumber=y; }
    virtual bool displayChildNumber() const { return m_displayChildNumber; }

    virtual PlusMinusButton* expandButton() const { return m_button; };

    virtual bool hasActionWidget() const { return false; };
    virtual bool hasControlWidget() const { return true; }
    virtual QRect actionWidgetGeometry() const { return QRect(); };
    virtual QRect controlWidgetGeometry() const;

    virtual void drawContents( QPainter* p, const QPoint& pos, const QRect& clipRect ) const;

protected:
    virtual int heightForWidth(int width) const;

protected slots:
    virtual void slotControlToggled(bool on);

private:
    bool m_displayChildNumber;
    PlusMinusButton *m_button;
    QString m_text;
};

class EventViewGroupItem : public EventViewHeaderItem
{
public:
    EventViewGroupItem(EventView *ev);
    virtual ~EventViewGroupItem();

    virtual void setIcon(const QString& icon);
    virtual QRect controlWidgetGeometry() const;
    virtual void drawContents( QPainter* p, const QPoint& pos, const QRect& clipRect ) const;
protected:
    virtual int heightForWidth(int width) const;
private:
    QString m_icon;
    bool m_hasIcon;
};

};

#endif

==> eventwatcher-0.4.2.tar.bz2: eventwatcher-0.4.2/src/mainwidget.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Sandro Giessl                                   *
 *   ceebx@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef EVENTWATCHERMAINWIDGET_H
#define EVENTWATCHERMAINWIDGET_H

#include <qmap.h>

#include <kpushbutton.h>

#include "eventview.h"

class QToolButton;

namespace EventWatcher {

// class EventView;
// class EventItem;
class EventViewItem;
class EventViewHeaderItem;
class EventViewGroupItem;

typedef QMap<QString,EventViewGroupItem*> EventViewGroupMap;

class MainWidget : public QWidget
{
Q_OBJECT
public:
    MainWidget(QWidget *parent = 0, const char *name = 0);
    virtual ~MainWidget();
public slots:
    virtual void slotEventAdded(EventItem* event);
    virtual void slotCopy();
    virtual void slotDelete();
    virtual void slotKeep();
    virtual void slotSelectAll();
    virtual void slotSetGroupItems(bool group);
    virtual void slotSetShowDeleteButtons(bool show);
    virtual void slotSetSmallActionButtons(bool small);
    virtual void slotDeleteItem(EventViewItem* item);
    virtual void slotKeepItem(EventViewItem* item);
signals:
    void itemsSelected(bool yes);
private slots:
    void slotUpdate();
    void slotSelectionChanged(int selected);
private:
    QString groupKey(const EventItem* event) const;
    EventView *m_eventView;
    EventViewHeaderItem *m_oldHeader;
    EventViewHeaderItem *m_newHeader;
    EventViewGroupMap m_groupMap;
};

class EventActionButton : public KPushButton
{
Q_OBJECT
public:
    EventActionButton(uint eventId, EventAction action, QWidget *parent = 0, const char *name = 0);
    virtual ~EventActionButton();
protected:
    QDragObject * dragObject();
protected slots:
    void buttonClicked();
private:
    uint m_eventId;
    EventAction m_action;
};

class EventViewItem : public QObject, public EventViewItemBase
{
Q_OBJECT
public:
    EventViewItem(bool showDelete, bool showKeep, bool smallActionButton, EventView *ev);
    virtual ~EventViewItem();

    virtual bool isSelectable() const { return true; }

    virtual void setGrouped(bool grouped) { m_grouped = grouped; }
    virtual bool grouped() const { return m_grouped; }

    virtual void setMarginLeft(int margin);
    virtual int marginLeft() const;

    virtual void setEventItem(const EventItem* item);
    virtual const EventItem* eventItem() const;

    virtual bool hasActionWidget() const;
    virtual bool hasControlWidget() const;
    virtual bool hasKeepWidget() const;
    virtual QRect actionWidgetGeometry() const;
    virtual QRect controlWidgetGeometry() const;
    virtual QRect keepWidgetGeometry() const;

    virtual void drawContents( QPainter* p, const QPoint& pos, const QRect& clipRect ) const;

protected:
    virtual int heightForWidth(int width) const;

signals:
    void deleteItem(EventViewItem* item);
    void keepItem(EventViewItem* item);

protected slots:
    virtual void slotControlClicked();
    virtual void slotKeepClicked();

private:
    bool m_grouped;
    int m_marginLeft;

    QSimpleRichText *m_rt;

    QToolButton *m_button;

    const EventItem *m_eventItem;
    bool m_hasAction;
    bool m_hasControlDelete;
    bool m_hasControlKeep;
    bool m_smallActionButton;
};

class EventViewHeaderItem : public QObject, public EventViewItemBase
{
Q_OBJECT
public:
    EventViewHeaderItem(EventView *ev);
    virtual ~EventViewHeaderItem();

    virtual bool isSelectable() const { return false; }

    virtual void setText(const QString& text) { m_text = text; };
    virtual const QString& text() const { return m_text; };

    virtual void setDisplayChildNumber(bool y) { m_displayChildNumber=y; }
    virtual bool displayChildNumber() const { return m_displayChildNumber; }

    virtual PlusMinusButton* expandButton() const { return m_button; };

    virtual bool hasActionWidget() const { return false; };
    virtual bool hasControlWidget() const { return true; };
    virtual bool hasKeepWidget() const { return false; };
    virtual QRect actionWidgetGeometry() const { return QRect(); };
    virtual QRect controlWidgetGeometry() const;
    virtual QRect keepWidgetGeometry() const { return QRect(); };

    virtual void drawContents( QPainter* p, const QPoint& pos, const QRect& clipRect ) const;

protected:
    virtual int heightForWidth(int width) const;

protected slots:
    virtual void slotControlToggled(bool on);

private:
    bool m_displayChildNumber;
    PlusMinusButton *m_button;
    QString m_text;
};

class EventViewGroupItem : public EventViewHeaderItem
{
public:
    EventViewGroupItem(EventView *ev);
    virtual ~EventViewGroupItem();

    virtual void setIcon(const QString& icon);
    virtual QRect controlWidgetGeometry() const;
    virtual void drawContents( QPainter* p, const QPoint& pos, const QRect& clipRect ) const;
protected:
    virtual int heightForWidth(int width) const;
private:
    QString m_icon;
    bool m_hasIcon;
};

};

#endif
